@@ -1,5 +1,18 @@
 #!/bin/bash
 
+echo "install script for Rot[t]Log v.$VERSION"
+echo
+
+echo -n "Checking for sed... "
+SED=$(which sed)
+if [ -z "$SED" ]; then
+  echo
+  echo "This installation script requires (GNU) sed."
+  echo "Please install it before to run this script."
+  exit 99
+fi
+echo "Done"
+
 . ./VERSION
 
 source ./DefConf.inc
@@ -7,9 +20,7 @@ source ./DefConf.inc
 DOCFILES="COPYING ChangeLog README INSTALL TODO sample_monthly sample_rc"
 MANFILES="rottlog.8 rottlogex.5"
 
-echo "install script for Rot[t]Log v.$VERSION"
-echo
-echo "Updating bash codes..."
+echo "Updating bash codes... "
 
 esc_MAINPATH=${ROTT_ETCDIR//\//\\/}
 esc_STATPATH=${ROTT_STATPATH//\//\\/}
@@ -35,6 +46,22 @@ else
   mv newvirottrc virottrc
 fi
 
+echo "Updating man pages..."
+for M in $MANFILES; do
+  posnum=${#M}
+  posnum=$[ posnum - 1 ]
+  number=${M:posnum}
+  sed -e s/\@ETCDIR/$esc_MAINPATH/ \
+      -e s/\@STATDIR/$esc_STATPATH/ > new-manual-$M
+  if [ ! -s new-manual-$M ]; then
+    echo "Error using sed to modify $M!!"
+    echo "Please send to stefko5@inwind.it an e-mail with as much as possible"
+    echo "detailed information about error messages and you environnement."
+    echo "I'll try to solve this problem as soon as possible. Thanks."
+    exit 3
+  fi
+  mv new-manual-$M $M
+done
 
 mkdir -p $BINDIR
 rm -f $BINDIR/rottlog
